.. _driver/jpeg:

``jpeg`` Driver
=====================

The ``jpeg`` driver specifies a TensorStore backed by a jpeg.
The read volume is indexed by "height" (y), "width" (x), "channel".

.. json:schema:: driver/jpeg

